==> org.At.tair.db_3.11.4.tar.gz: org.At.tair.db/man/org.At.tairSYMBOL.Rd <==
\name{org.At.tairSYMBOL}
\alias{org.At.tairSYMBOL}
\title{Map between TAIR Identifiers and Gene Symbols}
\description{
  org.At.tairSYMBOL is an R object that provides mappings between
  TAIR identifiers and gene abbreviations. 
}
\details{
  Each TAIR identifier is mapped to an abbreviation for the
  corresponding gene. An \code{NA} is reported if there is no known
  abbreviation for a given gene.
  
  Symbols typically consist of 3 letters that define either a single
  gene (ABC) or multiple genes (ABC1, ABC2, ABC3). Gene symbols can be
  used as key words to query public databases such as Entrez Gene.
  
  Mappings were based on data provided by: Tair  
  https://www.arabidopsis.org/download\_files/Public\_Data\_Releases/TAIR\_Data\_20190331/gene\_aliases\_20190402.txt.gz  
  With a date stamp from the source of: 2020-Apr01
  
}

\references{
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.At.tairSYMBOL
# Get the tair identifiers that are mapped to a gene symbol
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the SYMBOL for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
}

\keyword{datasets}

==> org.At.tair.db_3.12.0.tar.gz: org.At.tair.db/man/org.At.tairSYMBOL.Rd <==
\name{org.At.tairSYMBOL}
\alias{org.At.tairSYMBOL}
\title{Map between TAIR Identifiers and Gene Symbols}
\description{
  org.At.tairSYMBOL is an R object that provides mappings between
  TAIR identifiers and gene abbreviations. 
}
\details{
  Each TAIR identifier is mapped to an abbreviation for the
  corresponding gene. An \code{NA} is reported if there is no known
  abbreviation for a given gene.
  
  Symbols typically consist of 3 letters that define either a single
  gene (ABC) or multiple genes (ABC1, ABC2, ABC3). Gene symbols can be
  used as key words to query public databases such as Entrez Gene.
  
  Mappings were based on data provided by: Tair  
  https://www.arabidopsis.org/download\_files/Public\_Data\_Releases/TAIR\_Data\_20190630/gene\_aliases\_20190630.txt.gz  
  With a date stamp from the source of: 2020-Sep28
  
}

\references{
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.At.tairSYMBOL
# Get the tair identifiers that are mapped to a gene symbol
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the SYMBOL for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
}

\keyword{datasets}
